@@ -38,7 +38,6 @@ import re
 # regular expression matching leading whitespaces not until the first line
 # containing non-white-spaces
 RE_LSPACES = re.compile(r'\A(\s*$.)*', re.DOTALL | re.MULTILINE)
-RE_COMMAND_NAME = re.compile(r'^[a-z]+(-[a-z]+)*$')
 
 class LmiBaseCommand(object):
     """
@@ -159,7 +158,7 @@ class LmiBaseCommand(object):
 
         :returns: List of command strings as given on command line up to this
             command.
-        :rtype: list 
+        :rtype: list
         """
         if self.parent is not None:
             return self.parent.cmd_name_args + [self.cmd_name]
@@ -240,4 +239,3 @@ class LmiBaseCommand(object):
         :rtype: integer
         """
         raise NotImplementedError("run method must be overriden in subclass")
-
