@@ -40,9 +40,8 @@ def make_list_command(func,
         verify_func=None,
         transform_func=None):
     """
-    Create a command subclassed from
-    :py:class:`lmi.scripts.common.command.command.LmiLister`.
-    Please refer to this class for detailed usage.
+    Create a command subclassed from :py:class:`~.lister.LmiLister`. Please
+    refer to this class for detailed usage.
 
     :param func: Contents of ``CALLABLE`` property.
     :type func: string or callable
@@ -50,13 +49,10 @@ def make_list_command(func,
         it will be made from the name of associated function.
     :param tuple columns: Contents of ``COLUMNS`` property.
     :param callable verify_func: Callable overriding
-        py:meth:`lmi.scripts.common.command.command.LmiEndPointCommand.verify_options`
-        method.
+        py:meth:`~.endpoint.LmiEndPointCommand.verify_options` method.
     :param callable transform_func: Callable overriding
-        :py:meth:`lmi.scripts.common.command.command.LmiEndPointCommand.transform_options`
-        method.
-    :returns:  Subclass of
-        :py:class:`lmi.scripts.common.command.command.LmiLister`.
+        :py:meth:`~.endpoint.LmiEndPointCommand.transform_options` method.
+    :returns:  Subclass of :py:class:`~.lister.LmiLister`.
     :rtype: type
     """
     if name is None:
@@ -82,8 +78,7 @@ def register_subcommands(command_name, usage, command_map):
     :param string usage: Usage string parseable by ``docopt``.
     :param dictionary command_map: Dictionary of subcommands. Associates
         command names to their factories.
-    :returns: Subclass of
-        :py:class:`lmi.scripts.common.command.command.LmiCommandMultiplexer`.
+    :returns: Subclass of :py:class:`~.multiplexer.LmiCommandMultiplexer`.
     :rtype: type
     """
     props = { 'COMMANDS'   : command_map
