@@ -46,7 +46,6 @@ from lmi.scripts.common import get_logger
 from lmi.scripts.common import errors
 from lmi.scripts.common.command import base
 from lmi.scripts.common.command import util
-from lmi.shell import LMIUtil
 from lmi.shell import LMIInstance
 from lmi.shell.LMIReturnValue import LMIReturnValue
 
@@ -235,6 +234,8 @@ def _make_render_with_properties(properties, target_formatter_lister=False):
                     LOG().error('failed to render property "%s": %s',
                             prop[0], exc)
                 value = "ERROR"
+        if value is None:
+            value = ''
         return prop_name, value
 
     if target_formatter_lister:
@@ -441,8 +442,8 @@ class EndPointCommandMetaClass(abc.ABCMeta):
            and len(argspec.args) < cls.dest_pos_args_count()):
             raise errors.LmiCommandInvalidCallable(
                     dcl['__module__'], name,
-                    'Callable must accept at least %d positional'
-                    ' arguments' % base.dest_pos_args_count())
+                    'Callable must accept at least %d positional arguments' %
+                    cls.dest_pos_args_count())
 
         return cls
 
@@ -503,9 +504,8 @@ class ShowInstanceMetaClass(SessionCommandMetaClass):
         ``PROPERTIES`` : ``tuple``
             List of instance properties to print. Optional property.
 
-    These are translated in a
-    :py:meth:`lmi.scripts.common.command.command.LmiShowInstance.render`,
-    which should be marked as abstract in base lister class.
+    These are translated in a :py:meth:`~.show.LmiShowInstance.render`, which
+    should be marked as abstract in base lister class.
     """
 
     def __new__(mcs, name, bases, dcl):
@@ -535,8 +535,8 @@ class CheckResultMetaClass(SessionCommandMetaClass):
             Value to compare against the return value. Mandatory property.
 
     ``EXPECT`` property is transformed into a
-    :py:meth:`lmi.scripts.common.command.command.LmiCheckResult.check_result`
-    method taking two arguments ``(options, result)`` and returning a boolean.
+    :py:meth:`.checkresult.LmiCheckResult.check_result` method taking two
+    arguments ``(options, result)`` and returning a boolean.
     """
 
     def __new__(mcs, name, bases, dcl):
@@ -561,8 +561,8 @@ class CheckResultMetaClass(SessionCommandMetaClass):
                         result = result.rval
                     passed = expect == result
                     if not passed:
-                        LOG().info('expected "%s", got "%s"', expected, result)
-                        return (False, '%s != %s' % (expected, result))
+                        LOG().info('expected "%s", got "%s"', expect, result)
+                        return (False, '%s != %s' % (expect, result))
                     return passed
                 _new_expect.expected = expect
             del dcl['EXPECT']
@@ -600,7 +600,7 @@ class MultiplexerMetaClass(abc.ABCMeta):
                         'keys of COMMANDS dictionary must contain command'
                         ' names as strings')
             for cmd_name, cmd in cmds.items():
-                if not base.RE_COMMAND_NAME.match(cmd_name):
+                if not util.RE_COMMAND_NAME.match(cmd_name):
                     raise errors.LmiCommandInvalidName(
                             module_name, name, cmd_name)
                 if not issubclass(cmd, base.LmiBaseCommand):
