@@ -36,6 +36,26 @@ expects different argument, please refer to doc string of particular class.
 """
 
 import itertools
+import locale
+import os
+import pywbem
+
+from lmi.scripts.common import errors
+from lmi.scripts.common.formatter import command as fcmd
+
+def get_terminal_width():
+    """
+    Get the number of columns of current terminal if attached to it. It
+    defaults to 79 characters.
+
+    :returns: Number of columns of attached terminal.
+    :rtype: integer
+    """
+    try:
+        term_cols = int(os.popen('stty size', 'r').read().split()[1])
+    except (IOError, OSError, ValueError):
+        term_cols = 79  # fallback
+    return term_cols
 
 class Formatter(object):
     """
@@ -44,7 +64,8 @@ class Formatter(object):
     It produces string representation of given argument and prints it.
 
     This formatter supports following commands:
-        :py:class:`NewHostCommand`.
+
+        * :py:class:`~.command.NewHostCommand`.
 
     :param file stream: Output stream.
     :param integer padding: Number of leading spaces to print at each line.
@@ -59,6 +80,25 @@ class Formatter(object):
         self.out = stream
         self.padding = padding
         self.no_headings = no_headings
+        #: counter of hosts printed
+        self.host_counter = 0
+        #: counter of tables produced for current host
+        self.table_counter = 0
+        #: counter of lines producted for current table
+        self.line_counter = 0
+
+    @property
+    def encoding(self):
+        """
+        Try to determine encoding for output terminal.
+
+        :returns: Encoding used to encode unicode strings.
+        :rtype: string
+        """
+        enc = getattr(self.out, 'encoding')
+        if not enc:
+            enc = locale.getpreferredencoding()
+        return enc
 
     def render_value(self, val):
         """
@@ -69,7 +109,7 @@ class Formatter(object):
         :rtype: str
         """
         if isinstance(val, unicode):
-            return val.encode('utf-8')
+            return val.encode(self.encoding)
         if not isinstance(val, str):
             val = str(val)
         return val
@@ -89,6 +129,7 @@ class Formatter(object):
         """
         self.out.write(' ' * self.padding + line.format(*args, **kwargs))
         self.out.write("\n")
+        self.line_counter += 1
 
     def print_host(self, hostname):
         """
@@ -96,24 +137,35 @@ class Formatter(object):
 
         :param string hostname: Hostname to print.
         """
-        self.out.write("="*79 + "\n")
+        if (  self.host_counter > 0
+           or self.table_counter > 0
+           or self.line_counter > 0):
+            self.out.write("\n")
+        term_width = get_terminal_width()
+        self.out.write("="*term_width + "\n")
         self.out.write("Host: %s\n" % hostname)
-        self.out.write("="*79 + "\n")
+        self.out.write("="*term_width + "\n")
+        self.host_counter += 1
+        self.table_counter = 0
+        self.line_counter = 0
 
     def produce_output(self, data):
         """
         Render and print given data.
 
-        Data can be also instance of :py:class:`FormatterCommand`, see
-        documentation of this class for list of allowed commands.
+        Data can be also instance of
+        :py:class:`~.command.FormatterCommand`, see
+        documentation of this class for list of
+        allowed commands.
 
         This shall be overridden by subclasses.
 
         :param data: Any value to print. Subclasses may specify their
             requirements for this argument. It can be also am instance of
-            :py:class:`FormatterCommand`.
+            :py:class:`~.command.FormatterCommand`.
         """
         self.print_line(str(data))
+        self.line_counter += 1
 
 class ListFormatter(Formatter):
     """
@@ -122,7 +174,9 @@ class ListFormatter(Formatter):
     items, one occupying single line (row).
 
     This formatter supports following commands:
-        NewHostCommand, NewTableCommand, NewTableHeaderCommand.
+        * :py:class:`~.command.NewHostCommand`
+        * :py:class:`~.command.NewTableCommand`
+        * :py:class:`~.command.NewTableHeaderCommand`
 
     The command must be provided as content of one row. This row is then not
     printed and the command is executed.
@@ -131,7 +185,6 @@ class ListFormatter(Formatter):
     """
     def __init__(self, stream, padding=0, no_headings=False):
         super(ListFormatter, self).__init__(stream, padding, no_headings)
-        self.want_header = True
         self.column_names = None
 
     def print_text_row(self, row):
@@ -140,7 +193,8 @@ class ListFormatter(Formatter):
 
         :param tuple row: Data to print.
         """
-        self.out.write(self.render_value(row))
+        self.out.write(" "*self.padding + self.render_value(row) + "\n")
+        self.line_counter += 1
 
     def print_row(self, data):
         """
@@ -148,27 +202,21 @@ class ListFormatter(Formatter):
 
         :param tuple data: Data to print.
         """
-        if self.want_header:
+        if self.line_counter == 0 and not self.no_headings:
             self.print_header()
         self.print_text_row(data)
 
-    def print_host(self, hostname):
-        """
-        Prints header for new host.
-
-        :param string hostname: Hostname to print.
-        """
-        super(ListFormatter, self).print_host(hostname)
-        self.want_header = True
-
     def print_table_title(self, title):
         """
         Prints title of next tale.
 
         :param string title: Title to print.
         """
-        self.out.write("\n%s:\n" % title)
-        self.want_header = True
+        if self.table_counter > 0 or self.line_counter > 0:
+            self.out.write('\n')
+        self.out.write("%s:\n" % title)
+        self.table_counter += 1
+        self.line_counter = 0
 
     def print_header(self):
         """ Print table header. """
@@ -176,24 +224,23 @@ class ListFormatter(Formatter):
             return
         if self.column_names:
             self.print_text_row(self.column_names)
-        self.want_header = False
 
     def produce_output(self, rows):
         """
         Prints list of rows.
 
-        There can be a :py:class:`FormatterCommand` instance instead of a row.
-        See documentation of this class for list of allowed commands.
+        There can be a :py:class:`~.command.FormatterCommand` instance instead
+        of a row. See documentation of this class for list of allowed commands.
 
         :param rows:  List of rows to print.
-        :type rows: list or generator
+        :type rows: list, generator or :py:class:`.command.FormatterCommand`
         """
         for row in rows:
-            if isinstance(row, NewHostCommand):
+            if isinstance(row, fcmd.NewHostCommand):
                 self.print_host(row.hostname)
-            elif isinstance(row, NewTableCommand):
+            elif isinstance(row, fcmd.NewTableCommand):
                 self.print_table_title(row.title)
-            elif isinstance(row, NewTableHeaderCommand):
+            elif isinstance(row, fcmd.NewTableHeaderCommand):
                 self.column_names = row.columns
             else:
                 self.print_row(row)
@@ -208,9 +255,9 @@ class TableFormatter(ListFormatter):
     and the table is printed at once.
 
     This formatter supports following commands:
-        * :py:class:`NewHostCommand`
-        * :py:class:`NewTableCommand`
-        * :py:class:`NewTableHeaderCommand`
+        * :py:class:`~.command.NewHostCommand`
+        * :py:class:`~.command.NewTableCommand`
+        * :py:class:`~.command.NewTableHeaderCommand`
 
     The command must be provided as content of one row. This row is then not
     printed and the command is executed.
@@ -222,10 +269,13 @@ class TableFormatter(ListFormatter):
     def print_text_row(self, row, column_size):
         for i in xrange(len(row)):
             size = column_size[i]
-            item = self.render_value(unicode(row[i]).ljust(size))
+            item = self.render_value(row[i])
+            if i < len(row) - 1:
+                item = item.ljust(size)
             self.out.write(item)
             self.out.write(" ")
         self.out.write("\n")
+        self.line_counter += 1
 
     def print_stash(self):
         if not self.stash:
@@ -273,14 +323,18 @@ class TableFormatter(ListFormatter):
         :param string title: Title to print.
         """
         self.print_stash()
-        self.out.write("\n%s:\n" % title)
+        if self.table_counter > 0 or self.line_counter > 0:
+            self.out.write('\n')
+        self.out.write("%s:\n" % title)
+        self.table_counter += 1
+        self.line_counter = 0
 
     def produce_output(self, rows):
         """
         Prints list of rows.
 
-        There can be a :py:class:`FormatterCommand` instance instead of a row.
-        See documentation of this class for list of allowed commands.
+        There can be :py:class:`~.command.FormatterCommand` instance instead of
+        a row. See documentation of this class for list of allowed commands.
 
         :param rows: List of rows to print.
         :type rows: list or generator
@@ -293,15 +347,15 @@ class CsvFormatter(ListFormatter):
     Renders data in a csv (Comma-separated values) format.
 
     This formatter supports following commands:
-        * :py:class:`NewHostCommand`
-        * :py:class:`NewTableCommand`
-        * :py:class:`NewTableHeaderCommand`
+        * :py:class:`~.command.NewHostCommand`
+        * :py:class:`~.command.NewTableCommand`
+        * :py:class:`~.command.NewTableHeaderCommand`
     """
 
     def render_value(self, val):
         if isinstance(val, basestring):
             if isinstance(val, unicode):
-                val.encode('utf-8')
+                val.encode(self.encoding)
             val = '"%s"' % val.replace('"', '""')
         elif val is None:
             val = ''
@@ -311,23 +365,24 @@ class CsvFormatter(ListFormatter):
 
     def print_text_row(self, row):
         self.print_line(",".join(self.render_value(v) for v in row))
+        self.line_counter += 1
 
 class SingleFormatter(Formatter):
     """
-    Meant to render and print attributes of single object.
-    Attributes are rendered as a list of assignments of values to
-    variables (attribute names).
+    Meant to render and print attributes of single object. Attributes are
+    rendered as a list of assignments of values to variables (attribute names).
 
     This formatter supports following commands:
-        * :py:class:`NewHostCommand`
+        * :py:class:`~.command.NewHostCommand`
     """
 
     def produce_output(self, data):
         """
         Render and print attributes of single item.
 
-        There can be a :py:class:`FormatterCommand` instance instead of a data. See
-        documentation of this class for list of allowed commands.
+        There can be a :py:class:`~.command.FormatterCommand` instance instead
+        of a data. See documentation of this class for list of allowed
+        commands.
 
         :param data: Is either a pair of property names with list of values or
             a dictionary with property names as keys. Using the pair allows to
@@ -335,7 +390,7 @@ class SingleFormatter(Formatter):
             the properties will be sorted by the property names.
         :type data: tuple or dict
         """
-        if isinstance(data, NewHostCommand):
+        if isinstance(data, fcmd.NewHostCommand):
             self.print_host(data.hostname)
             return
 
@@ -353,6 +408,7 @@ class SingleFormatter(Formatter):
                     sorted(data.keys()))
         for name, value in dataiter:
             self.print_line("{0}={1}", name, value)
+            self.line_counter += 1
 
 class ShellFormatter(SingleFormatter):
     """
@@ -360,13 +416,13 @@ class ShellFormatter(SingleFormatter):
     as a shell script.
 
     This formatter supports following commands:
-        * :py:class:`NewHostCommand`
+        * :py:class:`~.command.NewHostCommand`
     """
 
     def render_value(self, val):
         if isinstance(val, basestring):
             if isinstance(val, unicode):
-                val.encode('utf-8')
+                val.encode(self.encoding)
             val = "'%s'" % val.replace("'", "\\'")
         elif val is None:
             val = ''
@@ -374,34 +430,38 @@ class ShellFormatter(SingleFormatter):
             val = str(val)
         return val
 
-class FormatterCommand(object):
+class ErrorFormatter(ListFormatter):
     """
-    Base class for formatter commands.
+    Render error strings for particular host. Supported commands:
+        * :py:class:`~.command.NewHostCommand`
     """
-    pass
+    def __init__(self, stream, padding=4):
+        super(ErrorFormatter, self).__init__(stream, padding)
 
-class NewHostCommand(FormatterCommand):
-    """
-    Command for formatter to finish current table (if any), print
-    header for new host and (if there are any data) print table header.
-    """
-    def __init__(self, hostname):
-        self.hostname = hostname
+    def print_row(self, data):
+        if isinstance(data, Exception):
+            if isinstance(data, pywbem.CIMError):
+                self.print_text_row("%s: %s" % (data.args[1], data.message))
+            elif not isinstance(data, errors.LmiFailed):
+                self.print_text_row("(%s) %s" % (data.__class__.__name__,
+                    str(data)))
+            else:
+                self.print_text_row(data)
+        else:
+            self.print_text_row(data)
 
-class NewTableCommand(FormatterCommand):
-    """
-    Command for formatter to finish current table (if any), print
-    the **title** and (if there are any data) print table header.
-    """
-    def __init__(self, title=None):
-        self.title = title
+    def print_host(self, hostname):
+        self.out.write("host %s\n" % hostname)
+        self.host_counter += 1
+        self.table_counter = 0
+        self.line_counter = 0
+
+    def produce_output(self, rows):
+        for row in rows:
+            if isinstance(row, fcmd.NewHostCommand):
+                self.print_host(row.hostname)
+            elif isinstance(row, fcmd.NewTableCommand):
+                self.print_table_title(row.title)
+            else:
+                self.print_row(row)
 
-class NewTableHeaderCommand(FormatterCommand):
-    """
-    Command for formatter to finish current table (if any), store new table
-    header and (if there are any data) print the table header.
-    The table header will be printed in all subsequent tables, until
-    new instance of this class arrives.
-    """
-    def __init__(self, columns=None):
-        self.columns = columns
